@@ -21,10 +21,9 @@
 
 #include <ModemManagerQt/GenericTypes>
 #include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem3Gpp>
 #include <ModemManagerQt/ModemDevice>
 
-#include <modem3gpp.h>
-
 class ProfileSettings;
 class Sim;
 class AvailableNetwork;
